// Copyright (C) 2024 Philipp Hofer
//
// Licensed under the EUPL, Version 1.2 or - as soon they will be approved by
// the European Commission - subsequent versions of the EUPL (the "Licence").
// You may not use this work except in compliance with the Licence.
//
// You should have received a copy of the European Union Public License along
// with this program.  If not, you may obtain a copy of the Licence at:
// <https://joinup.ec.europa.eu/software/page/eupl>
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the Licence is distributed on an "AS IS" basis,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the Licence for the specific language governing permissions and
// limitations under the Licence.

use std::{collections::HashMap, fs, path::Path};

pub(crate) struct Parts {
    parts: HashMap<String, String>,
}

impl Parts {
    pub(crate) fn new() -> Self {
        let mut parts = HashMap::new();
        let parts_path = Path::new("templates/parts");
        for part in fs::read_dir(parts_path).expect("No templates/parts folder") {
            let part = part.unwrap();
            let filename = part.file_name().into_string().unwrap().to_string();
            let filename = filename.replace(".html", "");
            let path = format!("{}", part.path().display());

            let template = fs::read_to_string(path).unwrap();

            parts.insert(filename, template);
        }
        Self { parts }
    }

    pub(crate) fn perform(&self, input: String) -> String {
        let mut input = input;
        for (key, value) in &self.parts {
            let replace = format!("{{{{{key}}}}}");
            input = input.replace(&replace, value);
        }
        input
    }
}
